phoenix_datatables v0.4.4 PhoenixDatatables.Response.Payload
A struct which serialies with Jason to the json response expected by the
Datatables client library.
A struct which serialies with Jason to the json response expected by the
Datatables client library.